import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../../cubit/bottom_nav_cubit.dart';
import '../../cubit/settings_cubit.dart';

import '../widgets/app_bar.dart';
import '../widgets/bottom_nav_bar.dart';

import 'demo_page.dart';
import 'graph_page.dart';
import 'about_page.dart';
import 'settings_page.dart';

class SkeletonScreen extends StatefulWidget {
  const SkeletonScreen({super.key});

  @override
  State<SkeletonScreen> createState() => _SkeletonScreenState();
}

class _SkeletonScreenState extends State<SkeletonScreen> {
  @override
  Widget build(BuildContext context) {
    const List<Widget> pageNavigation = <Widget>[
      DemoPage(),
      GraphPage(),
      SettingsPage(),
      AboutPage(),
    ];

    return BlocProvider<SettingsCubit>(
      create: (BuildContext context) => SettingsCubit(),
      child: BlocProvider<BottomNavCubit>(
        create: (BuildContext context) => BottomNavCubit(),
        child: Scaffold(
          extendBodyBehindAppBar: false,
          appBar: StandardAppBar(),
          body: BlocBuilder<BottomNavCubit, int>(
            builder: (BuildContext context, int state) {
              return AnimatedSwitcher(
                  duration: const Duration(milliseconds: 300),
                  child: pageNavigation.elementAt(state));
            },
          ),
          bottomNavigationBar: const BottomNavBar(),
          backgroundColor: Theme.of(context).colorScheme.background,
        ),
      ),
    );
  }
}
